@@ -134,7 +134,8 @@ create TABLE server (
 	max_rate integer default 0,						-- Max API rate per minute, 0 means no limit
 	vonage_application_id text,
 	vonage_webhook_secret text,
-	sec_mgr_del boolean default false
+	sec_mgr_del boolean default false,
+	api_max_records integer default 0				-- Maximum number of records to return via API
 	);
 ALTER TABLE server OWNER TO ws;
 
@@ -508,6 +509,7 @@ insert into groups(id,name) values(11,'manage tasks');
 --insert into groups(id,name) values(12,'dashboard');
 --insert into groups(id,name) values(13,'links');
 insert into groups(id,name) values(14,'console admin');
+insert into groups(id,name) values(15,'mcp access');
 
 insert into user_group (u_id, g_id) values (1, 1);
 insert into user_group (u_id, g_id) values (1, 2);
@@ -570,11 +572,11 @@ CREATE TABLE upload_event (
 	payload text			-- SMS details, in future XML submission details
 	);
 create index idx_ue_ident on upload_event(user_name);
-create index idx_ue_applied on upload_event (status, incomplete, results_db_applied);
 create index idx_ue_upload_time on upload_event (upload_time);
 create index idx_ue_processed_time on upload_event (processed_time);
 CREATE index ue_survey_ident ON upload_event(ident);
 CREATE INDEX idx_ue_p_id ON upload_event(p_id);
+CREATE INDEX idx_ue_pending ON upload_event (results_db_applied, queued, incomplete, ue_id);
 ALTER TABLE upload_event OWNER TO ws;
 
 DROP TABLE IF EXISTS option CASCADE;
@@ -1082,6 +1084,7 @@ SELECT AddGeometryColumn('tasks', 'geo_point_actual', 4326, 'POINT', 2);
 CREATE INDEX task_task_group ON tasks(tg_id);
 create index idx_tasks_del_auto on tasks (deleted, assign_auto);
 create index tasks_survey_idx on tasks(survey_ident);
+CREATE INDEX idx_tasks_tg_schedule_desc ON tasks(tg_id, schedule_at DESC); 
 ALTER TABLE public.tasks OWNER TO ws;
 
 CREATE TABLE public.locations (
@@ -1215,6 +1218,7 @@ CREATE TABLE public.linked_forms (
 	user_ident text,
 	download_time TIMESTAMP WITH TIME ZONE
 );
+create index if not exists linked_forms_idx on linked_forms(linked_s_id);
 ALTER TABLE public.linked_forms OWNER TO ws;
 
 DROP SEQUENCE IF EXISTS form_dependencies_seq CASCADE;
@@ -1422,6 +1426,8 @@ create TABLE people (
 	when_requested_subscribe TIMESTAMP WITH TIME ZONE		-- prevent spamming
 	);
 create unique index idx_people on people(o_id, email);
+create index if not exists opted_in_people_idx on people(opted_in);
+create index if not exists unsub_people_idx on people(unsubscribed);
 ALTER TABLE people OWNER TO ws;
 
 DROP SEQUENCE IF EXISTS mailout_seq CASCADE;
